==> fbreader-sources-0.8.7.tgz: fbreader-0.8.7/fbreader/src/formats/pdb/PdbPlugin.h <==
/*
 * FBReader -- electronic book reader
 * Copyright (C) 2004-2007 Nikolay Pultsin <geometer@mawhrin.net>
 * Copyright (C) 2005 Mikhail Sobolev <mss@mawhrin.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef __PDBPLUGIN_H__
#define __PDBPLUGIN_H__

#include <shared_ptr.h>

#include "../FormatPlugin.h"

class PdbPlugin : public FormatPlugin {

protected:
	PdbPlugin();

public:
	virtual ~PdbPlugin();

protected:
	std::string fileType(const ZLFile &file) const;
};

class PluckerPlugin : public PdbPlugin {

public:
	bool providesMetaInfo() const;
	bool acceptsFile(const ZLFile &file) const;
	bool readDescription(const std::string &path, BookDescription &description) const;
	bool readModel(const BookDescription &description, BookModel &model) const;
	const std::string &iconName() const;
};

class SimplePdbPlugin : public PdbPlugin {

public:
	bool providesMetaInfo() const;
	bool readDescription(const std::string &path, BookDescription &description) const;
	bool readModel(const BookDescription &description, BookModel &model) const;

protected:
	virtual shared_ptr<ZLInputStream> createStream(ZLFile &file) const = 0;
	virtual void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
};

class PalmDocLikePlugin : public SimplePdbPlugin {

public:
	const std::string &tryOpen(const std::string &path) const;

protected:
	shared_ptr<ZLInputStream> createStream(ZLFile &file) const;
};

class PalmDocPlugin : public PalmDocLikePlugin {

public:
	bool acceptsFile(const ZLFile &file) const;
	const std::string &iconName() const;

	void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;

private:
	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const std::string &fileName);
};

class MobipocketPlugin : public PalmDocLikePlugin {

public:
	bool acceptsFile(const ZLFile &file) const;
	const std::string &iconName() const;

	void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
};

class ZTXTPlugin : public SimplePdbPlugin {

public:
	bool acceptsFile(const ZLFile &file) const;
	const std::string &iconName() const;

protected:
	shared_ptr<ZLInputStream> createStream(ZLFile &file) const;

private:
	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const std::string &fileName);
};

inline PdbPlugin::PdbPlugin() {}

#endif /* __PDBPLUGIN_H__ */

==> fbreader-sources-0.12.1.tgz: fbreader-0.12.1/fbreader/src/formats/pdb/PdbPlugin.h <==
/*
 * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef __PDBPLUGIN_H__
#define __PDBPLUGIN_H__

#include <shared_ptr.h>

#include "../FormatPlugin.h"

class PdbPlugin : public FormatPlugin {

public:
	static std::string fileType(const ZLFile &file);

protected:
	PdbPlugin();

public:
	virtual ~PdbPlugin();
};

class PluckerPlugin : public PdbPlugin {

public:
	bool providesMetaInfo() const;
	bool acceptsFile(const ZLFile &file) const;
	bool readMetaInfo(Book &book) const;
	bool readModel(BookModel &model) const;
	const std::string &iconName() const;
};

class SimplePdbPlugin : public PdbPlugin {

public:
	bool readMetaInfo(Book &book) const;
	bool readModel(BookModel &model) const;

protected:
	virtual shared_ptr<ZLInputStream> createStream(ZLFile &file) const = 0;
	virtual void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
};

class PalmDocLikePlugin : public SimplePdbPlugin {

public:
	bool providesMetaInfo() const;
	const std::string &tryOpen(const std::string &path) const;

protected:
	shared_ptr<ZLInputStream> createStream(ZLFile &file) const;
};

class PalmDocPlugin : public PalmDocLikePlugin {

public:
	bool acceptsFile(const ZLFile &file) const;
	const std::string &iconName() const;

	void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;

private:
	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const std::string &fileName);
};

class MobipocketPlugin : public PalmDocLikePlugin {

private:
	bool acceptsFile(const ZLFile &file) const;
	const std::string &iconName() const;
	bool readMetaInfo(Book &book) const;

	void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
	shared_ptr<ZLImage> coverImage(const Book &book) const;
};

class EReaderPlugin : public SimplePdbPlugin {

public:
	bool providesMetaInfo() const;
	bool acceptsFile(const ZLFile &file) const;
	const std::string &iconName() const;
	bool readMetaInfo(Book &book) const;
	const std::string &tryOpen(const std::string &path) const;

	void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
protected:
	shared_ptr<ZLInputStream> createStream(ZLFile &file) const;
};

class ZTXTPlugin : public SimplePdbPlugin {

public:
	bool providesMetaInfo() const;
	bool acceptsFile(const ZLFile &file) const;
	const std::string &iconName() const;

protected:
	shared_ptr<ZLInputStream> createStream(ZLFile &file) const;

private:
	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const std::string &fileName);
};

inline PdbPlugin::PdbPlugin() {}

#endif /* __PDBPLUGIN_H__ */
